@@ -18,8 +18,8 @@
 DtrellScat <-
 function(form,data)  {
   
-  if (!("manipulate"  %in% .packages())) {
-    return(cat(paste0("You must be on R Studio with package manipulate attached\n",
+  if (!("manipulate"  %in% installed.packages())) {
+    return(cat(paste0("You must be on R Studio with package manipulate installed\n",
                       "in order to run this function.")))
   }
   
@@ -95,4 +95,4 @@ function(form,data)  {
   
 }
 
-if(getRversion() >= "2.15.1")  utils::globalVariables(c("picker", "level","band","reg","lev","analysis"))
+if(getRversion() >= "2.15.1")  utils::globalVariables(c("level","band","reg","lev","analysis"))
