@@ -3,7 +3,8 @@
 #' @description Employs the normal approximation to perform test for one or two proportions.
 #' 
 #' @rdname proptestGC
-#' @usage proptestGC(x,n=numeric(),p=NULL,data=parent.frame(),alternative="two.sided",
+#' @usage proptestGC(x,data=parent.frame(),n=numeric(),p=NULL,
+#'                          alternative=c("two.sided","less","greater"),
 #'                          success="yes",first=NULL,conf.level=0.95,
 #'                          correct=TRUE,graph=FALSE,verbose=TRUE)
 #' @param x Either a formula or a numeric vector.  If formula, it must be of the form ~x
@@ -47,18 +48,19 @@
 #' 
 #' #Summary data:
 #' #In one sample, 40 successes in 100 trials.  Testing whether p = 0.45.
-#' proptestGC(40,100,p=0.45,correct=TRUE)
+#' proptestGC(x=40,n=100,p=0.45,correct=TRUE)
 #' 
 #' #Want less output?  Set argument verbose to FALSE:
 #' proptestGC(~sex+seat,data=m111survey,success="2_middle",p=0.33,verbose=FALSE)
 proptestGC <-
-  function(x,n=numeric(),
-           p=NULL,data=parent.frame(),
-           alternative="two.sided",
+  function(x,data=parent.frame(),n=numeric(),
+           p=NULL,
+           alternative=c("two.sided","less","greater"),
            success="yes",first=NULL,
            conf.level=0.95,
            correct=TRUE,graph=FALSE,verbose=TRUE)  {
     
+    alternative <- match.arg(alternative)
     statistic <- FALSE
     p.value <- FALSE #these will get numerical values if a test is to be performed
     
@@ -138,7 +140,7 @@ proptestGC <-
         flip <- FALSE
         if (!is.null(first)) {
           if (!(first %in% unique(explanatory))) {
-            stop(paste(first,"is not a value of",explanatory))}
+            stop(paste(first,"is not a value of the variable",expname))}
           if (sort(unique(explanatory))[1]!=first) flip <- TRUE
         }
         
@@ -302,4 +304,179 @@ proptestGC <-
       
     }#end summary data treatment
     
-  }#end proptestGC
\ No newline at end of file
+  }#end proptestGC
+
+
+#' @title Print Function for GC Proportion Test (One-Sample)
+
+#' @description Utility print function
+#' @keywords internal
+#' 
+#' @rdname print.gcp1test
+#' @method print gcp1test
+#' @usage 
+#' \S3method{print}{gcp1test}(x,...)
+#' @param x An object of class gcp1test.
+#' @param \ldots ignored
+#' @return Output to the console.
+#' @author Homer White \email{hwhite0@@georgetowncollege.edu}
+#' @export 
+print.gcp1test <- function(x,...)  {
+  gcp1test <- x
+  verbose <- gcp1test$verbose
+  
+  odigits <- getOption("digits")
+  options(digits=4)
+  
+  cat("\n\nInferential Procedures for a Single Proportion p:\n")
+  if (!is.na(gcp1test$variable)) {
+    cat("\tVariable under study is",gcp1test$variable,"\n")
+  } else cat("\tResults based on Summary Data\n")
+  if (gcp1test$correct==TRUE) {
+    cat("\tContinuity Correction Applied to Test Statistic\n")
+  }
+  
+  tab <- gcp1test$SummTab
+  
+  if (verbose) {
+    cat("\n\n")
+    cat("Descriptive Results:\n\n")
+    
+    print(tab)
+    
+    cat("\n")
+    cat("\n")
+  }
+  checker <- min(tab[1,1],tab[1,2]-tab[1,1])
+  if (checker < 10) {
+    cat("WARNING:  Either the number of successes or \nthe number of failures is below 10.\nThe normal approximation for confidence intervals\nand P-value may be unreliable\n\n\n")
+  }
+  
+  
+  if (verbose) {  
+    cat("Inferential Results:\n\n")
+    cat("Estimate of p:\t",tab[1,3],"\n")
+    cat("SE(p.hat):\t",gcp1test$se,"\n\n")
+  }
+  cat(gcp1test$conf.level*100,"% Confidence Interval for p:\n\n",sep="")
+  int <- gcp1test$interval
+  cat(sprintf("%-10s%-20s%-20s","","lower.bound","upper.bound"),"\n")
+  cat(sprintf("%-10s%-20f%-20f","",int[1],int[2]),"\n\n")
+  
+  if (gcp1test$p.value) {
+    if (verbose) {
+      cat("Test of Significance:\n\n")
+      symbol <- switch(gcp1test$alternative,
+                       less="<",
+                       greater=">",
+                       two.sided="!=")
+      cat("\tH_0:  p =",gcp1test$p,"\n")
+      cat("\tH_a:  p",symbol,gcp1test$p,"\n\n")
+    }
+    cat("\tTest Statistic:\t\tz =",gcp1test$statistic,"\n")
+    cat("\tP-value:\t\tP =",gcp1test$p.value,"\n")
+    
+    Grapher <- function(stat,alt) {
+      rstat <- round(stat,2)
+      switch(alt,
+             less=invisible(pnormGC(rstat,region="below",graph=T)),
+             greater=invisible(pnormGC(rstat,region="above",graph=T)),
+             two.sided=invisible(pnormGC(c(-abs(rstat),abs(rstat)),region="outside",graph=T))
+      )
+    }
+    
+    if (gcp1test$graph) {
+      Grapher(stat=gcp1test$statistic,alt=gcp1test$alternative)
+    }
+    
+  }
+  
+  options(digits=odigits)
+}
+
+
+#' @title Print Function for GC Proportions Test (Two-Sample)
+
+#' @description Utility print function
+#' @keywords internal
+#' 
+#' @rdname print.gcp2test
+#' @method print gcp2test
+#' @usage 
+#' \S3method{print}{gcp2test}(x,...)
+#' @param x An object of class gcp2test.
+#' @param \ldots ignored
+#' @return Output to the console.
+#' @author Homer White \email{hwhite0@@georgetowncollege.edu}
+#' @export
+print.gcp2test <- function(x,...)  {
+  gcp2test <- x
+  verbose <- gcp2test$verbose
+  
+  odigits <- getOption("digits")
+  options(digits=4)
+  
+  cat("\n\nInferential Procedures for the Difference of Two Proportions p1-p2:\n")
+  if (!is.na(gcp2test$explanatory)) {
+    cat("\t",gcp2test$response,"grouped by",gcp2test$explanatory,"\n")
+  } else cat("\tResults taken from summary data.\n")
+  
+  tab <- gcp2test$SummTab
+  
+  if (verbose) {
+    cat("\n\n")
+    cat("Descriptive Results:\n\n")
+    
+    print(tab)
+    
+    cat("\n")
+    cat("\n")
+  }
+  
+  checker <- min(tab[1,1],tab[2,1],tab[1,2]-tab[1,1],tab[2,2]-tab[2,1])
+  if (checker < 10) {
+    cat("WARNING:  In at least one of the two groups\n",
+        "number of successes or number of failures is below 10.\n",
+        "The normal approximation for confidence intervals\n",
+        "and P-value may be unreliable.\n\n",sep="")
+  }
+  
+  if (verbose) {
+    cat("Inferential Results:\n\n")
+    cat("Estimate of p1-p2:\t",tab[1,3]-tab[2,3],"\n")
+    cat("SE(p1.hat - p2.hat):\t",gcp2test$se,"\n\n")
+  }
+  cat(gcp2test$conf.level*100,"% Confidence Interval for p1-p2:\n\n",sep="")
+  int <- gcp2test$interval
+  cat(sprintf("%-10s%-20s%-20s","","lower.bound","upper.bound"),"\n")
+  cat(sprintf("%-10s%-20f%-20f","",int[1],int[2]),"\n\n")
+  
+  if(gcp2test$p.value) {
+    if (verbose) { 
+      cat("Test of Significance:\n\n")
+      symbol <- switch(gcp2test$alternative,
+                       less="<",
+                       greater=">",
+                       two.sided="!=")
+      cat("\tH_0:  p1-p2 = 0\n")
+      cat("\tH_a:  p1-p2",symbol,"0\n\n")
+    }
+    cat("\tTest Statistic:\t\tz =",gcp2test$statistic,"\n")
+    cat("\tP-value:\t\tP =",gcp2test$p.value,"\n")
+    
+    Grapher <- function(stat,alt) {
+      rstat <- round(stat,2)
+      switch(alt,
+             less=invisible(pnormGC(rstat,region="below",graph=T)),
+             greater=invisible(pnormGC(rstat,region="above",graph=T)),
+             two.sided=invisible(pnormGC(c(-abs(rstat),abs(rstat)),region="outside",graph=T))
+      )
+    }
+    
+    if (gcp2test$graph) {
+      Grapher(stat=gcp2test$statistic,alt=gcp2test$alternative)
+    }
+    
+  }
+  options(digits=odigits)
+}
